@@ -20,47 +20,6 @@ function(hclu, k=NULL, h=NULL)
     coupe.out
 }
 
-.identity.model <-
-function(Y.lvs, IDM, SCE0, split.a, split.b)
-{    
-    # INPUT
-    # Y.lvs: matrix containing the estimated latent variables
-    # IDM: Inner Design Matrix
-    # SCE0: Suma de cuadrados de errores nodo padre
-    # split.a: elements of split a (left split)
-    # split.b: elements of split b (right split)
-
-    # PARAMS
-    lvs <- ncol(Y.lvs)# number of latent variables
-    endo <- rowSums(IDM)
-    endo[endo!=0] <- 1  # endogenous vector   
-    SCE1 <- 0# initialize SCE1
-    p <- 0# initialize p
-
-    for (aux1 in 2:lvs) {
-        if (endo[aux1] == 1) {
-            indep <- which(IDM[aux1,1:aux1]==1)
-            reg <- cbind(Y.lvs[,aux1], Y.lvs[,indep])
-            # Split regression matrix into "Xa" and "Xb"
-            Xa <- reg[split.a,]
-            Xb <- reg[split.b,]
-            # SCE1 calculation
-            lm.resa <- summary(lm(Xa[,1] ~ Xa[,2:ncol(Xa)]))$residuals
-            lm.resb <- summary(lm(Xb[,1] ~ Xb[,2:ncol(Xb)]))$residuals
-            SCE1 <- SCE1 + sum(lm.resa^2) + sum(lm.resb^2)
-            p <- p + ncol(reg)
-        }
-    }
-    m <- sum(endo)
-    n <- m * (length(split.a) + length(split.b))
-    f <- ((n-2*p)/p)  *  ((SCE0 - SCE1)/SCE1)  # F statistic
-    df1 <- p   # degrees of freedom
-    df2 <- n - 2*p# degrees of freedom
-    p.val <- 1 - pf(f, df1, df2)   # p.value
-    iden <- c(f, df1, df2, p.val)   # result
-    return(iden)
-}
-
 .innerplot <-
 function(path.coefs, arr.pos=arr.pos, box.prop=box.prop, 
                        box.cex=box.cex, cex.txt=cex.txt)
@@ -111,226 +70,6 @@ function(IDM, modes, blocks, loadings, arr.pos=arr.pos,
     }
 }
 
-.nominal.split <-
-function(v)
-{
-    # INPUT(S)
-    # v: vector containing the nominal categories
-
-    # PARAM(S)
-    k = length(v)   # length of vector
-    num.parts = (2^(k-1))-1   # number of binary partitions
-    # stop limit of order of partitions
-    if ((k%%2)==0) stop.parts=k/2 else stop.parts=(k-1)/2    
-    part = as.list(1:num.parts)    # list for warehousing the partitions
-    antipar = part   # complementary list for part
-
-    # FUNCTION(S)
-    # internal function for evaluating candidates splits
-    eval.cand = function(x, y, aux)
-    {
-        # x: list of partitions
-        # y: candidate split to be included in part
-        # aux: num of parts already included in part
-        acum = 0
-        for (i in 1:(aux-1))
-        {
-             true.false = setequal(x[[i]], y)
-             if (true.false) acum=acum+1 else acum=acum+0
-        }
-        return(acum)
-    }
-       
-    # first order partitions
-    aux = 1
-    for (i in 1:k)
-    {
-         part[[aux]] = v[i]
-         antipar[[aux]] = setdiff(v, part[[i]])
-         aux = aux + 1
-    }
-    
-    # partitions of order greater than one
-    for (ord in 2:stop.parts)
-    {
-        if (stop.parts < ord)
-            break
-        # partitions of the immediate past order
-        p1 = aux - choose(k, (ord-1))
-        p2 = aux - 1
-        part.ant = part[p1:p2]
-        antipar.ant = antipar[p1:p2]    
-        for (i in 1:length(part.ant))
-        { 
-             part1 = part.ant[[i]]
-             anti1 = antipar.ant[[i]]
-             for (j in 1:length(anti1))
-             {
-                  candidat = c(part1, anti1[j])
-                  cand = eval.cand(part, candidat, aux)
-                  if (cand==0)
-                  {
-                       part[[aux]] = candidat
-                       antipar[[aux]] = setdiff(v, candidat)
-                       aux = aux + 1
-                  } else
-                  {
-                       next
-                  }
-             }
-        }
-    }    
-    # in case that k is even, only select partitions until num.parts
-    if (length(part) > num.parts)
-    {
-        part = part[1:num.parts]
-        antipar = antipar[1:num.parts]
-    }   
-    parts = list(par1=part, par2=antipar)
-    return(parts)
-}
-
-.ordinal.split <-
-function(cat.exe)
-{
-    a = length(cat.exe)
-    if (a == 2)  # binary variable
-    {
-        part = cat.exe[1]
-        antipar = cat.exe[2]
-    }
-    if (a > 2)   # more than 2 categories
-    {
-        part = as.list(1:(a-1))
-        antipar = part
-        for (i in 1:(a-1))
-        {
-             part[[i]] = cat.exe[1:i]
-             antipar[[i]] = setdiff(cat.exe, part[[i]])
-        }
-    }
-    parts = list(par1=part, par2=antipar)
-    return(parts)
-}
-
-.partition <-
-function(pls, DT, EXEV, type.exev, elemnod, nv, size)
-{
-    # INPUT(S)
-    # pls: object of class pls
-    # DT: data table
-    # EXEV: matrix of external explanatory variables
-    # type.exev: vector of type (ordinals or nominals)
-    # elemnod: vector of labeled elements according to node
-    # nv: node value
-    # size: minimum number of elements inside a node
-
-     # identifying which elements are in node "nv"
-     N <- nrow(EXEV)
-     if (nv==0) elems<-1:length(elemnod) else elems<-which(elemnod==nv)
-     indelem <- cbind(1:length(elems), elems)# adding identifier to elems
-     E.node <- EXEV[elems,]# select EXEV elements of current node      
-     exevs <- apply(E.node, 2, function(x) nlevels(as.factor(x)))# vector fo exevs
-     list.cata <- as.list(1:length(exevs))   # list of categs for best split.a
-     list.catb <- as.list(1:length(exevs))   # list of categs for best split.b
-     Ftest.global <- matrix(NA, length(exevs), 4)# matrix of results for best indent.mod
-
-     # parameters of plspm
-     Y.lvs <- pls$scores# matrix of latent variables
-     IDM <- pls$model$IDM# IDM matrix
-     blocks <- pls$model$blocks
-     modes <- pls$model$modes
-     scheme <- pls$model$scheme
-     scaled <- pls$model$scaled
-     tol <- pls$model$tol
-     iter <- pls$model$iter
-     pls.resid <- .pls.basic(DT, IDM, blocks, modes, scheme, scaled, tol, iter)
-     resid <- pls.resid$residuals# vector of residuals
-     SCE0 <- 0# Initialize SCE0
-     for (aux in 1:length(resid))
-          SCE0 <- SCE0 + sum(resid[[aux]]^2)     # calculating SCE0
-
-     # determining size limit
-     if (size < 1) {
-         size.limit <- ceiling(size*N)
-     } else {
-         size.limit <- size
-     }
-
-     # for each external explanatory variable
-     for (i in 1:length(exevs))    
-     {
-          if (exevs[i] == 1)  # category already used
-          {
-               Ftest.global[i,4] <- 1   # p.value of 1 (not significative)
-               list.cata[[i]] <- NA# NAs in categs split.a
-               list.catb[[i]] <- NA# NAs in categs split.b
-               next   # next exev
-          }  else   # category to be analized               
-          {
-               ### computing number of binary splits
-               cat.exe <- unique(E.node[,i])  # vector of categories
-               if (type.exev[i] == "ord") # for an ordinal variable
-               {
-                    bin.split <- .ordinal.split(sort(cat.exe))  # function of ordinal splits 
-               } else  # for a nominal variable
-               {
-                    if (exevs[i]==2)   # nominal var with 2 categories
-                    {
-                        bin.split <- as.list(cat.exe)
-                    } else     # nominal var > 2 categories
-                    { 
-                        bin.split <- .nominal.split(cat.exe)   # function of nominal splits
-                    }
-               }
-               ### Perform identity.model test for every binary split
-               Ftest <- matrix(NA, length(bin.split[[1]]), 4)   # matrix for identity.test results
-               for (aux in 1:length(bin.split[[1]]))   # for each binary split
-               {
-                     split.a <- which(E.node[,i] %in% bin.split[[1]][[aux]])# elems of left split
-                     split.b <- which(E.node[,i] %in% bin.split[[2]][[aux]])  # elems of right split
-                     n.a <- length(split.a)
-                     n.b <- length(split.b)
-                     if (n.a<=size.limit || n.b<=size.limit)# stop cond true
-                     {
-                          Ftest[aux,4] <- 1   # p.value of 1 (not significative)
-                          next  # next binary split
-                     } else# stop cond false
-                     {
-                          # identity.model test
-                          Ftest[aux,] <- .identity.model(Y.lvs, IDM, SCE0, split.a, split.b)
-                     }
-               }
-               ### select best split of the analized exev
-               for (aux in 1:nrow(Ftest))
-               {
-                    min.p <- which(Ftest[,4]==min(Ftest[,4]))[1]  # which split has the min p.value
-                    Ftest.global[i,] <- Ftest[min.p,]
-                    list.cata[[i]] <- bin.split[[1]][[min.p]]
-                    list.catb[[i]] <- bin.split[[2]][[min.p]]
-               } 
-          }
-     }
-     ### select optimum split
-     optim <- which(Ftest.global[,4]==min(Ftest.global[,4]))[1]
-     f.optim <- Ftest.global[optim,]
-     cats.optim <- list.cata[[optim]]
-     anticat.optim <- list.catb[[optim]]
-
-     aux.a <- which(E.node[,optim] %in% cats.optim)
-     aux.b <- which(E.node[,optim] %in% anticat.optim)
-     part.a <- indelem[aux.a,2]
-     part.b <- indelem[aux.b,2]
-     list.elems <- list(part.a, part.b)
-
-     ### return(result.part)
-     test.opt <- data.frame(exev=colnames(EXEV)[optim], F.test=f.optim[1], 
-                           df1=f.optim[2], df2=f.optim[3], p.val=f.optim[4])
-     categs <- list(as.vector(cats.optim), as.vector(anticat.optim))
-     resul <- list(inner.test=test.opt, categs=categs, list.elems=list.elems)
-     return(resul)
-}
-
 .path.scheme <-
 function(IDM, Y)
 {
@@ -346,65 +85,6 @@ function(IDM, Y)
     return(E)
 }
 
-.pls.basic <-
-function(DT, IDM, blocks, modes, scheme, scaled, tol, iter)
-{   
-    ##### PARAMETERS
-    DM <- DT
-    lvs <- nrow(IDM)
-    mvs <- sum(blocks)
-    blocklist <- as.list(1:lvs)
-    for (j in 1:lvs)
-         blocklist[[j]] <- rep(j,blocks[j])
-    blocklist <- unlist(blocklist)
-    endo = rowSums(IDM)
-    endo[endo!=0] = 1
-    plsr <- FALSE
-    ### Variable Names
-    lvs.names = colnames(IDM)
-    mvs.names = colnames(DM)
-
-    # apply the selected scaling
-    if (scaled) {
-        sd.X <- sqrt((nrow(DM)-1)/nrow(DM)) * apply(DM, 2, sd)
-        X <- scale(DM, scale=sd.X)
-    } else {
-        X <- scale(DM, scale=FALSE)
-    }
-    dimnames(X) <- list(rownames(DM), mvs.names)
-
-    # ==================== Stage 1: Iterative procedure ==================
-    out.ws <- .pls.weights(X, IDM, blocks, modes, scheme, tol, iter)
-    if (is.null(out.ws)) stop("The pls algorithm is non convergent") 
-    out.weights <- round(out.ws[[1]], 4)
-    cor.XY <- cor(X, X%*%out.ws[[2]])
-    w.sig <- rep(NA,lvs)
-    for (k in 1:lvs) 
-         w.sig[k] <- ifelse(sum(sign(cor.XY[which(blocklist==k),k]))<=0,-1,1)
-    Z.lvs <- X %*% out.ws[[2]] %*% diag(w.sig,lvs,lvs)
-    Y.lvs <- Z.lvs
-    if (!scaled) 
-        Y.lvs <- DM %*% out.ws[[2]] %*% diag(w.sig,lvs,lvs)
-    dimnames(Y.lvs) <- list(rownames(X), lvs.names)
-    dimnames(Z.lvs) <- list(rownames(X), lvs.names)
-    loadcomu <- .pls.loads(X, Y.lvs, blocks)    
-    loads <- loadcomu[[1]]
-
-    # ============ Stage 2: Path coefficients and total effects ==========
-    pathmod <- .pls.paths(IDM, Y.lvs, plsr)
-    innmod <- pathmod[[1]]
-    Path <- pathmod[[2]]
-    R2 <- pathmod[[3]]
-    residuals <- pathmod[[4]]
-
-    # ============================= Results ==============================
-    model <- list(IDM=IDM, blocks=blocks, scheme=scheme, modes=modes, 
-                  scaled=scaled, tol=tol, iter=iter)
-    resul = list(out.weights=out.weights, loadings=loads, scores=Y.lvs,   
-                 path.coefs=Path, R2=R2, residuals=residuals, model=model)
-    resul
-}
-
 .pls.boot <-
 function(DM, IDM, blocks, modes, scheme, scaled, br, plsr, tol, iter)
 {
